Skip to contents

Install a GitHub Action into a package repository to manage qcthat Quality Control with TriggerUAT(), CommentAllReports(), and AttachReleaseReports(). We recommend reviewing the generated action to determine whether you would like to turn any features off.

Usage

Action_qcthat(lglOverwrite = FALSE, strPkgRoot = ".")

Arguments

lglOverwrite

(length-1 logical) Whether to overwrite files if they already exist.

strPkgRoot

(length-1 character) The path to a directory in the package. Will be expanded using gert::git_find().

Value

The path to the created GitHub Action YAML file (invisibly).

Examples

if (FALSE) { # interactive()

  Action_qcthat()
}