Skip to contents

Determine the issue number associated with the current GitHub event, if the workflow was triggered by an "issues" event, or by a "workflow_dispatch" event with "issueNumber" input

Usage

GuessIssueNumber(lGHEventPayload = LoadGHEventPayload())

Arguments

lGHEventPayload

(list) The GitHub event payload. Defaults to the result of LoadGHEventPayload().

Value

An integer representing the issue number (if the event payload contains issue$number or inputs$issueNumber), or NULL if the event is not an "issues" event or the issue number cannot be found.