Skip to contents

Generate a report about the test status of specific issues.

Usage

QCIssues(
  intIssues,
  strPkgRoot = ".",
  strOwner = GetGHOwner(strPkgRoot),
  strRepo = GetGHRepo(strPkgRoot),
  strGHToken = gh::gh_token(),
  lglWarn = TRUE,
  chrIgnoredLabels = DefaultIgnoreLabels(),
  dfITM = NULL,
  envCall = rlang::caller_env()
)

Arguments

intIssues

(integer) A vector of issue numbers from a CompileIssueTestMatrix() matrix or from GitHub.

strPkgRoot

(length-1 character) The path to a directory in the package. Will be expanded using gert::git_find().

strOwner

(length-1 character) GitHub username or organization name.

strRepo

(length-1 character) GitHub repository name.

strGHToken

(length-1 character) GitHub token with permissions appropriate to the action being performed.

lglWarn

(length-1 logical) Whether to warn when an extra value is included in the filter (but the report still returns results). Defaults to TRUE.

chrIgnoredLabels

(character) GitHub labels to ignore, such as "qcthat-nocov".

dfITM

(qcthat_IssueTestMatrix) A qcthat_IssueTestMatrix object as returned by AsIssueTestMatrix() (often via QCPackage()).

envCall

(environment) The environment to use for error reporting. Typically set to rlang::caller_env().

Value

A qcthat_IssueTestMatrix object as returned by QCPackage(), filtered to the indicated issues.

Examples

if (FALSE) { # interactive()

  # This will only make sense if you are working in a git repository that has
  # issues #84 and #85 on GitHub.
  QCIssues(c(84, 85))
}