Install a GitHub Action into a package repository to manage qcthat Quality
Control with TriggerUAT(), CommentAllReports(), and
AttachReleaseReports(). We recommend reviewing the generated action to
determine whether you would like to turn any features off.
Arguments
- lglOverwrite
(
length-1 logical) Whether to overwrite files if they already exist.- strPkgRoot
(
length-1 character) The path to a directory in the package. Will be expanded usinggert::git_find().