Fetch the closers (commits or pull requests) for all closed issues in a
repository. In addition to formal ClosedEvents (where a commit or merged
PR directly closed the issue), this also includes ConnectedEvents (where a
merged PR was manually linked to the issue) that have not been subsequently
cancelled by a DisconnectedEvent. An issue may appear more than once if it
has multiple valid closers.
Usage
FetchRepoIssueClosers(
strOwner = GetGHOwner(),
strRepo = GetGHRepo(),
strGHToken = gh::gh_token()
)Value
A tibble::tibble() with columns:
Issue: Issue number.CloserType: Type of the closer, eitherCommitorPullRequest.CloserSHA: SHA of the commit that closed the issue. ForCommitclosers, this is the commit OID directly. ForPullRequestclosers, this is the merge commit SHA.CloserPRNumber: Number of the pull request that closed the issue, orNAif the issue was closed by a commit.CloserDate: Timestamp of the closing event as a character string.