A simple wrapper around QCPackage() that filters the resulting issue-test
matrix to only include issues that were closed as "completed".
Usage
QCCompletedIssues(
strPkgRoot = ".",
strOwner = GetGHOwner(strPkgRoot),
strRepo = GetGHRepo(strPkgRoot),
strGHToken = gh::gh_token(),
chrIgnoredLabels = DefaultIgnoreLabels(),
dfITM = NULL,
envCall = rlang::caller_env()
)Arguments
- strPkgRoot
(
length-1 character) The path to a directory in the package. Will be expanded usinggert::git_find().- strOwner
(
length-1 character) GitHub username or organization name.- strRepo
(
length-1 character) GitHub repository name.- strGHToken
(
length-1 character) GitHub token with permissions appropriate to the action being performed.- chrIgnoredLabels
(
character) GitHub labels to ignore, such as"qcthat-nocov".- dfITM
(
qcthat_IssueTestMatrix) Aqcthat_IssueTestMatrixobject as returned byAsIssueTestMatrix()(often viaQCPackage()).- envCall
(
environment) The environment to use for error reporting. Typically set torlang::caller_env().
Value
A qcthat_IssueTestMatrix object as returned by QCPackage(),
filtered to issues that were closed as completed.