Set up qcthat labels and GitHub Action workflow for a package repository.
This function combines SetupGHLabels() and Action_qcthat() to create
the necessary GitHub labels and install the GitHub Action workflow for
managing qcthat Quality Control. We recommend reviewing the generated action
to determine whether you would like to turn any features off.
Usage
use_qcthat(
dfLabels = DefaultIgnoreLabelsDF(),
lglOverwrite = FALSE,
strPkgRoot = ".",
strOwner = GetGHOwner(strPkgRoot),
strRepo = GetGHRepo(strPkgRoot),
strGHToken = gh::gh_token()
)Arguments
- dfLabels
(
data.frame) A data frame with columnsLabel,Description, andColor, specifying the labels to create. By default, this is the data frame returned byDefaultIgnoreLabelsDF(). Descriptions of labels created via this function are prefixed with"{qcthat}: "to make it easier to search for them in your list of labels.- lglOverwrite
(
length-1 logical) Whether to overwrite files if they already exist.- strPkgRoot
(
length-1 character) The path to a directory in the package. Will be expanded usinggert::git_find().- strOwner
(
length-1 character) GitHub username or organization name.- strRepo
(
length-1 character) GitHub repository name.- strGHToken
(
length-1 character) GitHub token with permissions appropriate to the action being performed.